(*
 * Copyright (c) 2015, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the "hack" directory of this source tree.
 *
 *)

(*
 * This function works by side effects. It is adding in the Naming_table the
 * nast produced from the filename passed as a parameter (the SharedMem must
 * thus have been initialized via SharedMem.init prior to calling this
 * function). Its performance benefits if the Parser_heap has been previously
 * populated. It also adds dependencies via Typing_deps.add_idep. It finally
 * adds all the typing information about classes, functions, typedefs,
 * respectively in the globals in Typing_env.Class, Typing_env.Fun, and
 * Typing_env.Typedef.
 *)
val make_env :
  sh:SharedMem.uses -> Provider_context.t -> Relative_path.t -> unit

val declare_const_in_file :
  write_shmem:bool ->
  Provider_context.t ->
  Relative_path.t ->
  string ->
  Typing_defs.decl_ty

val declare_record_def_in_file :
  write_shmem:bool ->
  Provider_context.t ->
  Relative_path.t ->
  string ->
  Typing_defs.record_def_type

val declare_typedef_in_file :
  write_shmem:bool ->
  Provider_context.t ->
  Relative_path.t ->
  string ->
  Typing_defs.typedef_type

(** /!\ LEGACY DECL ONLY
    Check whether the class is already in the heap and if not,
    declare it, its members and its ancestors and add them to
    their respective shared heaps. *)
val declare_folded_class_in_file :
  sh:SharedMem.uses ->
  Provider_context.t ->
  Relative_path.t ->
  string ->
  Decl_defs.decl_class_type

val declare_fun_in_file :
  write_shmem:bool ->
  Provider_context.t ->
  Relative_path.t ->
  string ->
  Typing_defs.fun_elt

val start_tracking : unit -> unit

val stop_tracking : unit -> FileInfo.names
